clear all
set memory 700m

*** define working directory here:
cd "c:\"
set more off

****************************************************************************************************
****************************************************************************************************
********************************** Data Merge and Filtering*****************************************
****************************************************************************************************
****************************************************************************************************

******************************
*** Ratings Data *************
******************************

use ratings_jan80_apr09, clear

	drop conm
	g stringyear = substr(datadate,5,4)
	g year = real(stringyear)
	drop stringyear
	g stringmonth = substr(datadate,1,2)
	g month=real(stringmonth)
	drop stringmonth
	drop if splticrm =="N.M." | splticrm=="Suspended"
	
	
* Investment grade ratings are coded 2, Non-Investment grade ratings are coded 1 and non-graded firms are coded 0.
	g ratings=0
	
	replace ratings=2 if splticrm=="AAA"|splticrm=="AA+"|splticrm =="AA"|splticrm =="AA-"|splticrm =="A+"|splticrm =="A" | ///
		splticrm =="A-" | splticrm =="BBB+" | splticrm =="BBB" | splticrm =="BBB-"
	
	replace ratings=1 if splticrm =="BB+"|splticrm =="BB"|splticrm =="BB-"|splticrm =="B+"|splticrm =="B"|splticrm =="B-" | ///
			splticrm =="CCC+"|splticrm =="CCC"|splticrm =="CCC-"| splticrm =="CC" | splticrm =="D" | splticrm=="SD" 

			
sort gvkey year month
save temp1, replace 

***********************************************
***** Compustat Quarterly Fundamentals Data ***
***********************************************

use compustat_q_jan80_apr09, clear

	sort gvkey fyearq fqtr datadate
	drop if gvkey==gvkey[_n+1] & fyearq==fyearq[_n+1] & fqtr==fqtr[_n+1]

* SIC - I delete the following SICs that refer to financials, government and non profitables (according to Murillo)
* ADR and ATQ - I delete ADRs using the adrrq variable and I delete those observations missing ATQ - Assets
	
	destring sic, replace
	
	** Filters 1 and 2 : Drop not-for-profit, governamental and financial
	keep if sic<8000
	keep if (sic<6000 | sic>=7000)

	** Filter 3 : Drop ADRs
	keep if missing(adrrq)
	
	** Filter: Drop if missing Total Assets
	drop if missing(atq)


	g stringyear = substr(datadate,5,4)
	g year = real(stringyear)
	drop stringyear

	g stringmonth = substr(datadate,1,2)
	g month=real(stringmonth)
	drop stringmonth

* capx is Capital Expenditures YTD, in fiscal calendar. So the adjustment below is to create Capital Expenditures Quarterly
	
	sort fyearq fqtr
	egen timeindex = group(fyearq fqtr)
	gen temp = real(gvkey)
	tsset temp timeindex
	g capx = d.capxy if fqtr~=1
	replace capx=capxy if fqtr==1
	replace capx=0 if capx<0
	drop if missing(capx)

	tsset, clear
	drop temp timeindex

	keep conm gvkey datadate year atq saleq cshoq cheq ibq dpq ceqq txditcq capx ppentq prccq sic fqtr fyr month

	sort gvkey year month

	**** Drop repeated observations

	drop if gvkey==gvkey[_n+1] & year==year[_n+1] & month==month[_n+1]

save temp2, replace

*** Merge the Quarterly Computast data with the Ratings Data
	
	merge gvkey year month using temp1
	drop if _merge==2
	drop _merge

	sort gvkey year month
	replace ratings=0 if missing(ratings)
	save data_quarterly, replace

*************************************************************
**** Compustat Fundamental Annual Data **********************
*************************************************************

	use compustat_a_jan80_apr09, clear
	sort gvkey fyear datadate
	keep gvkey datadate dd* dltt fyr fyear at sic adrr np
	gen temp = real(gvkey)
	drop if gvkey==gvkey[_n+1] & fyear==fyear[_n+1]
	tsset temp fyear

	tsset, clear
	drop temp

	destring sic, replace
	
	** Filters 1 and 2 : Drop not-for-profit, governamental and financial
	keep if sic<8000
	keep if (sic<6000 | sic>=7000)
	
	** Filter 3 : Drop ADRs
	keep if missing(adrr)

	g stringyear = substr(datadate,5,4)
	g year = real(stringyear)
	drop stringyear

	g stringmonth = substr(datadate,1,2)
	g month=real(stringmonth)
	drop stringmonth

	sort gvkey year month
	save data_annual, replace

******************************************************************
**** MERGING QUARTERLY AND ANNUAL DATA ***************************
******************************************************************

	use data_quarterly, clear
	merge gvkey year month using data_annual
	drop _merge
	sort gvkey year month
	keep gvkey conm year prccq atq saleq cshoq cheq ibq ceqq txditcq capx dpq ppentq dd* at* dltt sic fyear fqtr fyr datadate month ratings np
	
	g quarter=1 if month<=3
	replace quarter=2 if month>=4
	replace quarter=3 if month>=7
	replace quarter=4 if month>=10

	sort gvkey year quarter fyr
	drop if gvkey==gvkey[_n+1] & year==year[_n+1] & quarter==quarter[_n+1]

	save data1, replace

	erase temp1.dta
	erase temp2.dta
	erase data_quarterly.dta
	erase data_annual.dta

****************************************************************
********* More Filters ******************************************
****************************************************************

	use data1, clear
	sort year quarter
	egen timeindex = group(year quarter)
	sort gvkey year quarter
	gen temp = real(gvkey)
	drop gvkey
	ren temp gvkey

tsset gvkey timeindex
order gvkey datadate timeindex

* Filtering data

	*** Filter 5 : Drop if total assets <10
	drop if atq<10

	
	*** Filter 6: Drop if Asset Growth>100%
	
	g pctassetgrowth = atq/l.atq
	drop if pctassetgrowth>2 & pctassetgrowth!=.
	
	g logsize = log(atq)
	
	*** Filter 7: Drop Missing sales number
	drop if saleq==.
	
	*** Filter 8: Drop Negative sales
	drop if saleq<0

	
	*** Filter 9: Drop Growth of Sales>100%
	g salesgrowth = log(saleq/l.saleq)
	drop if salesgrowth>2 & salesgrowth!=.

	
	g mktvalcomp = prccq*cshoq

	*** Filter: Drop Missing and negative cash (no effect in 2007)
	drop if cheq==.
	drop if cheq<0

	
	
	**** Filter 10: Drop Firms with cash greater than assets
	g cashhold_a =cheq/atq
	drop if cashhold_a>=1

	
	g cf = ibq+dpq
	g cf_k = cf/l.ppentq
	g q = (atq+mktvalcomp-ceqq-txditcq)/atq
	
	*** Filter : Drop if investments greater than assets (no effect in 2007)
	g inv_a = capx/atq
	drop if inv_a>1
	
	*** Filter 11: Drop if PPE greater than Assets
	g ppe_a = ppentq/atq
	drop if ppe_a<0 | ppe_a>1
	
	g inv_k = capx/l.ppentq
	g LTLeverage = (dd1+dltt)/at
	g sic2 = int(sic/100)

order gvkey timeindex year quarter

***********************************************
*Specification Q3 Jan07-Sep07 vc Jan08 vs Sep08
***********************************************

	*** Generating dependent variable 
	quiet for @ in var logsize salesgrowth cashhold_a cf_k q inv_k capx : gen avglagQ3@ = (l1.@+l2.@+l3.@)/3
	quiet for @ in var logsize salesgrowth cashhold_a cf_k q inv_k capx: gen avgleadQ3@ =(f1.@+f2.@+f3.@)/3

	g dd6=dltt-dd5-dd4-dd3-dd2
	g sd1=dd1/(dd1+dltt)

	*** Filter 12: Drop if missing DD1 or missing DLTT
	drop if sd1>1 & dd1~=0


	**** Filter 13: Drop firms for which Notes Payable represent more than 1% of assets.
	keep if np/at<0.01
	
	*** Filter 14: Drop if DD1 + DLTT>Assets
	keep if ((dd1+dltt)/at)<1
	
	*** Filter 15: Drop if DLTT < DD2 + DD3 + DD4 + DD5
	keep if dd6>=0
	save temp, replace

***********************************************************************
* Datasets with fiscal year end month being SEP, OCT, NOV, DEC and JAN
* dQ3_more is for calculations using only the first 3 quarters of the year
***********************************************************************

	use temp, clear	
	
	*** Filter 16: Drop if fiscal year end months equal 2, 3, 4, 5, 6, 7, 8
	
	keep if fyr>=9 | fyr==1
	
	drop q cf_k cashhold_a logsize
	rename avglagQ3q q
	rename avglagQ3cf_k cf_k 	
	rename avglagQ3logsize logsize	
	rename avglagQ3cashhold_a cashhold_a
	g avglagQ3cashhold_a = cashhold_a 
	
	save dQ3_more, replace
	
	
	
****************************************************************************************************
****************************************************************************************************
************************************** Analysis****************************************************
****************************************************************************************************
****************************************************************************************************




************************************************************************************************
*Table 3 - Panel B - Matching estimator ATT
************************************************************************************************

** Loading data
use dQ3_more, clear

	keep if fyear==2007

*** Filter 17: Drop if DLTT over Assets<=5%
	keep if dltt/at > 0.05

*** Generating Treatment Variable	
	g t = 1 if sd1>.20 & !missing(sd1)
	replace t = 0 if sd1<=.20 & !missing(sd1)
	lab def treat 0 "Control" 1 "Treatment"
	lab values t treat

*** Filter 18: Drop if missin goutcome or control variable observation
	drop if missing(avgleadQ3inv_k) | missing(avglagQ3inv_k) | missing(q) | missing(cf_k) | missing(logsize) | missing(cashhold_a) | missing(LTLeverage)

	
** Winsorizing
	foreach x in avglagQ3inv_k avgleadQ3inv_k q cf_k logsize cashhold_a LTLeverage {
		winsor `x', gen(winsor1pct`x') p(0.005)
		drop `x'
		rename winsor1pct`x' `x'
	}

	g didQ3_inv_k = avgleadQ3inv_k - avglagQ3inv_k 
	tab t
	save gvkey_1067, replace
	
*** Matching firms	- Matching Estimator (ATT)
	nnmatch didQ3_inv_k t q cf_k logsize cashhold_a LTLeverage, exact(sic2 ratings) tc(att) m(1) robust(1) bias(bias) keep(s1) replace

************************************************************************************************
*Panel B - Before ("2007" Column)
************************************************************************************************

** Loading data	
	use dQ3_more, clear

	keep if fyear==2007

*** Filter 17: Drop if DLTT over Assets<=5%
	keep if dltt/at > 0.05

*** Generating Treatment Variable
	g t = 1 if sd1>.20 & !missing(sd1)
	replace t = 0 if sd1<=.20 & !missing(sd1)
	lab def treat 0 "Control" 1 "Treatment"
	lab values t treat

*** Filter 18: Drop if missin goutcome or control variable observation
	drop if missing(avgleadQ3inv_k) | missing(avglagQ3inv_k) | missing(q) | missing(cf_k) | missing(logsize) | missing(cashhold_a) | missing(LTLeverage)
	
** Winsorizing
	foreach x in avglagQ3inv_k q cf_k logsize cashhold_a LTLeverage {
		winsor `x', gen(winsor1pct`x') p(0.005)
		drop `x'
		rename winsor1pct`x' `x'
	}
	
	tab t

*** Matching firms
	nnmatch avglagQ3inv_k t q cf_k logsize cashhold_a LTLeverage, exact(sic2 ratings) tc(att) m(1) robust(1) bias(bias) keep(s1) replace
	
	use s1, clear

	g diff = avglagQ3inv_k_1 - avglagQ3inv_k_0

	* Numbers that go in column "2007" of panel A, the underline _1 means treated and the underline _0 means control firms

*** Treated Before (2007)
	reg avglagQ3inv_k_1, r
	
*** Control Before (2007)
	reg avglagQ3inv_k_0, r
	
*** Treated Before - Control Before (2007)
	reg diff, r
	
************************************************************************************************
*Panel B - After ("2008" Column)
************************************************************************************************

** Loading data
	
	use dQ3_more, clear

*** Filter 17: Drop if DLTT over Assets<=5%
	keep if fyear==2007
	
	keep if dltt/at > 0.05
	
*** Generating Treatment Variable
	g t = 1 if sd1>.20 & !missing(sd1)
	replace t = 0 if sd1<=.20 & !missing(sd1)
	lab def treat 0 "Control" 1 "Treatment"
	lab values t treat

*** Filter 18: Drop if missin goutcome or control variable observation
	drop if missing(avgleadQ3inv_k) | missing(avglagQ3inv_k) | missing(q) | missing(cf_k) | missing(logsize) | missing(cashhold_a) | missing(LTLeverage)
	

** Winsorizing
 
	foreach x in avgleadQ3inv_k q cf_k logsize cashhold_a LTLeverage {
		winsor `x', gen(winsor1pct`x') p(0.005)
		drop `x'
		rename winsor1pct`x' `x'
	}

	tab t
	
*** Matching firms
	nnmatch avgleadQ3inv_k t q cf_k logsize cashhold_a LTLeverage, exact(sic2 ratings) tc(att) m(1) robust(1) bias(bias) keep(s1) replace

	use s1, clear
	g diff = avgleadQ3inv_k_1 - avgleadQ3inv_k_0
	
* Numbers that go in column "2008" of panel A, the underline _1 means treated and the underline _0 means control firms

**** Treated After
	reg avgleadQ3inv_k_1, r

**** Control After
	reg avgleadQ3inv_k_0, r
	
**** Treated After - Control After
	reg diff, r

************************************************************************************************
*Panel B - Before - After and Diff in Diff Results ("2008-2007" column)
************************************************************************************************
** Loading data
use dQ3_more, clear

	keep if fyear==2007

*** Filter 17: Drop if DLTT over Assets<=5%
	keep if dltt/at > 0.05

*** Generating Treatment Variable	
	g t = 1 if sd1>.20 & !missing(sd1)
	replace t = 0 if sd1<=.20 & !missing(sd1)
	lab def treat 0 "Control" 1 "Treatment"
	lab values t treat

*** Filter 18: Drop if missing goutcome or control variable observation
	drop if missing(avgleadQ3inv_k) | missing(avglagQ3inv_k) | missing(q) | missing(cf_k) | missing(logsize) | missing(cashhold_a) | missing(LTLeverage)

	
** Winsorizing
	foreach x in avglagQ3inv_k avgleadQ3inv_k q cf_k logsize cashhold_a LTLeverage {
		winsor `x', gen(winsor1pct`x') p(0.005)
		drop `x'
		rename winsor1pct`x' `x'
	}

	g didQ3_inv_k = avgleadQ3inv_k - avglagQ3inv_k 
	tab t
	save gvkey_1067, replace
	
*** Matching Estimator (ATT) - (4th row of "2008-2007" column)
	nnmatch didQ3_inv_k t q cf_k logsize cashhold_a LTLeverage, exact(sic2 ratings) tc(att) m(1) robust(1) bias(bias) keep(s1) replace
	
	use s1, clear
	g diff = didQ3_inv_k_1 - didQ3_inv_k_0
	
* Numbers that go in column "difference" of panel A, the underline _1 means treated and the underline _0 means control firms

*** Treated After - Before
	reg didQ3_inv_k_1, r

*** Control After - Before
	reg didQ3_inv_k_0, r 
	
*** Diff in Diff Results
	reg diff, r



